==> quandoparte_0.3.4.tar.gz: quandoparte-0.3.4/application/resources/i18n/quandoparte_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>App</name>
    <message>
        <source>&lt;p&gt;%1&lt;/p&gt;&lt;p&gt;Copyright (c) 2010&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Licensed under the GNU Public License v2 or above&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;%1&lt;/p&gt;&lt;p&gt;Copyright © 2010&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Distribuito secondo la licenza GNU Public License v2 o superiore&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 version %2&lt;/p&gt;&lt;p&gt;Copyright (c) 2010&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Licensed under the GNU Public License v2 or above&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;%1 versione %2&lt;/p&gt;&lt;p&gt;Copyright © 2010&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Distribuito secondo la licenza GNU Public License v2 o superiore&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../app.cpp" line="135"/>
        <source>&lt;p&gt;%1 version %2&lt;/p&gt;&lt;p&gt;Copyright (c) 2010, 2011&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Licensed under the GNU Public License v2 or above&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 versione %2&lt;/p&gt;&lt;p&gt;Copyright © 2010, 2011&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Distribuito secondo la licenza GNU Public License v2 o superiore&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../settingsdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../settingsdialog.ui" line="25"/>
        <source>Show Last Station on Startup</source>
        <translation>Mostra l&apos;ultima stazione all&apos;avvio</translation>
    </message>
    <message>
        <source>Station:</source>
        <translation type="obsolete">Stazione:</translation>
    </message>
</context>
<context>
    <name>StationListModel</name>
    <message>
        <location filename="../../stationlistmodel.cpp" line="35"/>
        <source>Not a qpl file</source>
        <translation>Non è un file qpl</translation>
    </message>
</context>
<context>
    <name>StationListView</name>
    <message>
        <location filename="../../stationlistview.ui" line="14"/>
        <source>Station List</source>
        <translation>Elenco delle stazioni</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="37"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="53"/>
        <source>Near</source>
        <translation>Vicine</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="56"/>
        <source>Show near stations first</source>
        <translation>Mostra per prime le stazioni vicine</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="64"/>
        <source>ABC</source>
        <translation>ABC</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="67"/>
        <source>Sort stations by name</source>
        <translation>Ordina le stazioni per nome</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="72"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="77"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="85"/>
        <source>Recent</source>
        <translation>Recenti</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="88"/>
        <source>Show recently checked stations first</source>
        <translation>Mostra per prime le stazioni recenti</translation>
    </message>
</context>
<context>
    <name>StationView</name>
    <message>
        <location filename="../../stationview.cpp" line="37"/>
        <source>Arrivals</source>
        <translation>Arrivi</translation>
    </message>
    <message>
        <location filename="../../stationview.cpp" line="38"/>
        <source>Departures</source>
        <translation>Partenze</translation>
    </message>
    <message>
        <location filename="../../stationview.cpp" line="39"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../../stationview.cpp" line="40"/>
        <source>Change Station</source>
        <translation>Cambia stazione</translation>
    </message>
    <message>
        <location filename="../../stationview.cpp" line="41"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
</context>
</TS>

==> quandoparte_0.4.0-1.tar.gz: quandoparte-0.4.0/application/resources/i18n/quandoparte_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>App</name>
    <message>
        <source>&lt;p&gt;%1&lt;/p&gt;&lt;p&gt;Copyright (c) 2010&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Licensed under the GNU Public License v2 or above&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;%1&lt;/p&gt;&lt;p&gt;Copyright © 2010&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Distribuito secondo la licenza GNU Public License v2 o superiore&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 version %2&lt;/p&gt;&lt;p&gt;Copyright (c) 2010&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Licensed under the GNU Public License v2 or above&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;%1 versione %2&lt;/p&gt;&lt;p&gt;Copyright © 2010&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Distribuito secondo la licenza GNU Public License v2 o superiore&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../app.cpp" line="135"/>
        <source>&lt;p&gt;%1 version %2&lt;/p&gt;&lt;p&gt;Copyright (c) 2010, 2011&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Licensed under the GNU Public License v2 or above&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 versione %2&lt;/p&gt;&lt;p&gt;Copyright © 2010, 2011&lt;/p&gt;&lt;p&gt;Luciano Montanaro (mikelima@cirulla.net)&lt;/p&gt;&lt;p&gt;Distribuito secondo la licenza GNU Public License v2 o superiore&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../settingsdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../settingsdialog.ui" line="45"/>
        <source>Show Last Station on Startup</source>
        <translation>Mostra l&apos;ultima stazione all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../../settingsdialog.ui" line="52"/>
        <source>Update Display Periodically</source>
        <translation>Aggiorna stazione periodicamente</translation>
    </message>
    <message>
        <source>Station:</source>
        <translation type="obsolete">Stazione:</translation>
    </message>
</context>
<context>
    <name>StationListModel</name>
    <message>
        <location filename="../../stationlistmodel.cpp" line="35"/>
        <source>Not a qpl file</source>
        <translation>Non è un file qpl</translation>
    </message>
</context>
<context>
    <name>StationListView</name>
    <message>
        <location filename="../../stationlistview.ui" line="14"/>
        <source>Station List</source>
        <translation>Elenco delle stazioni</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="65"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="81"/>
        <source>Near</source>
        <translation>Vicine</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="84"/>
        <source>Show near stations first</source>
        <translation>Mostra per prime le stazioni vicine</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="92"/>
        <source>ABC</source>
        <translation>ABC</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="95"/>
        <source>Sort stations by name</source>
        <translation>Ordina le stazioni per nome</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="100"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="105"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="113"/>
        <source>Recent</source>
        <translation>Recenti</translation>
    </message>
    <message>
        <location filename="../../stationlistview.ui" line="116"/>
        <source>Show recently checked stations first</source>
        <translation>Mostra per prime le stazioni recenti</translation>
    </message>
</context>
<context>
    <name>StationView</name>
    <message>
        <location filename="../../stationview.cpp" line="39"/>
        <source>Arrivals</source>
        <translation>Arrivi</translation>
    </message>
    <message>
        <location filename="../../stationview.cpp" line="40"/>
        <source>Departures</source>
        <translation>Partenze</translation>
    </message>
    <message>
        <location filename="../../stationview.cpp" line="41"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../../stationview.cpp" line="42"/>
        <source>Change Station</source>
        <translation>Cambia stazione</translation>
    </message>
    <message>
        <location filename="../../stationview.cpp" line="43"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
</context>
</TS>
